cin=scanf=i=input
documentwrite=ip=cout=printf=P=p=ଦେଖ=see=देखना=आउटपुट_देखना=ي=изглед=视图=視圖=pogled=Pohled=udsigt=visie=vidon=vaade=näkymä=vue=Aussicht=θέα=נוף=melihat=Visualizza=見る=전망=skats=vaizdas=utsikt=widok=Visão=vedere=Посмотреть=поглед=vyhliadka=pogled=ver=se=намоиш=ดู=görünüm=вид=lượtxem=دیکھیں=వీక్షణ=பார்வை=पहा=കാണുക=pandangan=tingnan=vista=দৃশ্য=print

